@@ -52,10 +52,10 @@ class about : public QDialog, private Ui::AboutDlg{
       lb_name->setText(QString::fromUtf8("<b><h1>")+tr("qBittorrent")+QString::fromUtf8(" "VERSION"</h1></b>"));
       // Thanks
       te_thanks->append(QString::fromUtf8("<a name='top'></a>"));
-      te_thanks->append(QString::fromUtf8("<ul><li>I would like to thank sourceforge.net for hosting qBittorrent project.</li>"));
-      te_thanks->append(QString::fromUtf8("<li>I am happy that Ishan Arora and Arnaud Demaizière are contributing to the project as developers. Their help is greatly appreciated</li>"));
-      te_thanks->append(QString::fromUtf8("<li>I also want to thank Jeffery Fernandez (jeffery@qbittorrent.org), project consultant, RPM packager, for his help and support.</li>"));
-      te_thanks->append(QString::fromUtf8("<li>I am grateful to Peter Koeleman (peter@qbittorrent.org) who is helping port qBittorrent to Windows.</li>"));
+      te_thanks->append(QString::fromUtf8("<ul><li>I would first like to thank sourceforge.net for hosting qBittorrent project and for their support.</li>"));
+      te_thanks->append(QString::fromUtf8("<li>I am pleased that people from all over the world are contributing to qBittorrent: Ishan Arora (India), Arnaud Demaizière (France) and Stephanos Antaris (Greece). Their help is greatly appreciated</li>"));
+      te_thanks->append(QString::fromUtf8("<li>I also want to thank Jeffery Fernandez (jeffery@qbittorrent.org), project consultant, for his help and support since the beginning of this project.</li>"));
+      te_thanks->append(QString::fromUtf8("<li>I am grateful to Peter Koeleman (peter@qbittorrent.org) for working on qBittorrent port to Windows.</li>"));
       te_thanks->append(QString::fromUtf8("<li>Thanks a lot to our graphist Mateusz Toboła (tobejodok@qbittorrent.org) for his great work.</li></ul><br><br>"));
       te_thanks->scrollToAnchor(QString::fromUtf8("top"));
       // Translation
@@ -63,8 +63,8 @@ class about : public QDialog, private Ui::AboutDlg{
       te_translation->append(tr("I would like to thank the following people who volunteered to translate qBittorrent:")+QString::fromUtf8("<br>"));
       te_translation->append(QString::fromUtf8(
           "<i>- <u>Brazilian:</u> Nick Marinho (nickmarinho@gmail.com)<br>\
-          - <u>Bulgarian:</u> Tsvetan & Boiko Bankov (emerge_life@users.sourceforge.net)<br>\
-          - <u>Catalan:</u> Gekko Dam Beer (gekko04@users.sourceforge.net)<br>\
+          - <u>Bulgarian:</u> Tsvetan & Boyko Bankoff (emerge_life@users.sourceforge.net)<br>\
+          - <u>Catalan:</u> Francisco Luque Contreras (frannoe@ya.com)<br>\
           - <u>Chinese (Simplified):</u> Guo Yue (yue.guo0418@gmail.com)<br>\
           - <u>Chinese (Traditional):</u> Yi-Shun Wang (dnextstep@gmail.com)<br>\
           - <u>Czech:</u> Jirka Vilim (web@tets.cz)<br>\
@@ -75,22 +75,26 @@ class about : public QDialog, private Ui::AboutDlg{
           - <u>Greek:</u> Tsvetan Bankov (emerge_life@users.sourceforge.net)<br>\
           - <u>Hungarian:</u> Majoros Péter (majoros.peterj@gmail.com)<br>\
           - <u>Italian:</u> Mirko Ferrari (mirkoferrari@gmail.com) and Ferraro Luciano (luciano.ferraro@gmail.com)<br>\
-          - <u>Japanese:</u> Nardog (nardog@e2umail.com)<br>\
+          - <u>Japanese:</u> Nardog (alphisation@gmail.com)<br>\
           - <u>Korean:</u> Jin Woo Sin (jin828sin@users.sourceforge.net)<br>\
           - <u>Norwegian:</u> Lars-Erik Labori (hamil@users.sourceforge.net)<br>\
-          - <u>Polish:</u> Jarek Smieja (ajep9691@wp.pl)<br>\
+          - <u>Polish:</u> Mariusz Fik (fisiu@opensuse.org)<br>\
           - <u>Portuguese:</u> Nick Marinho (nickmarinho@gmail.com)<br>\
           - <u>Romanian:</u> Obada Denis (obadadenis@users.sourceforge.net)<br>\
           - <u>Russian:</u> Nick Khazov (m2k3d0n@users.sourceforge.net) and Alexey Morsov (samurai@ricom.ru)<br>\
+          - <u>Serbian:</u> Anaximandar Milet (anaximandar@operamail.com)<br>\
           - <u>Slovak:</u>  helix84<br>\
-          - <u>Spanish:</u> Vicente Raul Plata Fonseca (silverxnt@users.sourceforge.net) and Gabriel de Oliveira (deadloop@hotmail.com)<br>\
+          - <u>Spanish:</u> Francisco Luque Contreras (frannoe@ya.com)<br>\
           - <u>Swedish:</u> Daniel Nylander (po@danielnylander.se)<br>\
           - <u>Turkish:</u> Hasan YILMAZ (iletisim@hedefturkce.com) and Erdem Bingöl (erdem84@gmail.com)<br>\
-          - <u>Ukrainian:</u> Andrey Shpachenko (masterfix@users.sourceforge.net)<br><br>"));
+          - <u>Ukrainian:</u> Andrey Shpachenko (masterfix@users.sourceforge.net) and Oleh Prypin (blaxpirit@gmail.com)<br><br>"));
       te_translation->append(tr("Please contact me if you would like to translate qBittorrent into your own language."));
       te_translation->scrollToAnchor(QString::fromUtf8("top"));
       // License
       te_license->append(QString::fromUtf8("<a name='top'></a>"));
+#ifdef Q_WS_WIN
+      te_license->append(QString::fromUtf8("qBittorrent is licensed under the GNU General Public License version 2."));
+#else
       te_license->append(QString::fromUtf8("qBittorrent is licensed under the GNU General Public License version 2 with the\
 addition of the following special exception:\
 <br><br>\
@@ -437,6 +441,7 @@ exception statement from your version.</i>\
           consider it more useful to permit linking proprietary applications with the<br>\
           library.  If this is what you want to do, use the GNU Library General<br>\
           Public License instead of this License.<br>"));
+#endif
           te_license->scrollToAnchor(QString::fromUtf8("top"));
           show();
     }
