@@ -36,12 +36,13 @@
 
 using namespace libtorrent;
 
-class QString;
+#include <QString>
 class QStringList;
 
 // A wrapper for torrent_handle in libtorrent
 // to interact well with Qt types
 class QTorrentHandle {
+
   private:
     torrent_handle h;
 
@@ -52,7 +53,7 @@ class QTorrentHandle {
     //
 
     QTorrentHandle() {}
-    QTorrentHandle(torrent_handle h);
+    explicit QTorrentHandle(torrent_handle h);
 
     //
     // Getters
@@ -64,6 +65,7 @@ class QTorrentHandle {
     QString name() const;
     float progress() const;
     bitfield pieces() const;
+    void piece_availability(std::vector<int>& avail) const;
     void get_download_queue(std::vector<partial_piece_info>& queue) const;
     QString current_tracker() const;
     bool is_valid() const;
@@ -75,13 +77,14 @@ class QTorrentHandle {
     size_type total_wanted_done() const;
     float download_payload_rate() const;
     float upload_payload_rate() const;
+    int num_connections() const;
+    int connections_limit() const;
     int num_peers() const;
     int num_seeds() const;
     int num_complete() const;
     int num_incomplete() const;
     void scrape_tracker() const;
     QString save_path() const;
-    fs::path save_path_boost() const;
     QStringList url_seeds() const;
     size_type actual_size() const;
     int download_limit() const;
@@ -93,23 +96,40 @@ class QTorrentHandle {
     bool is_queued() const;
     QString file_at(unsigned int index) const;
     size_type filesize_at(unsigned int index) const;
-    std::vector<announce_entry> const& trackers() const;
+    std::vector<announce_entry> trackers() const;
     torrent_status::state_t state() const;
     QString creator() const;
     QString comment() const;
     size_type total_failed_bytes() const;
-    void file_progress(std::vector<size_type>& fp);
-    size_type total_payload_download();
-    size_type total_payload_upload();
-    size_type all_time_upload();
-    size_type all_time_download();
+    size_type total_redundant_bytes() const;
+    void file_progress(std::vector<size_type>& fp) const;
+    size_type total_payload_download() const;
+    size_type total_payload_upload() const;
+    size_type all_time_upload() const;
+    size_type all_time_download() const;
+    size_type total_done() const;
     QStringList files_path() const;
     int num_uploads() const;
     bool is_seed() const;
+    bool is_checking() const;
     bool is_auto_managed() const;
-    int active_time() const;
+    qlonglong active_time() const;
+    qlonglong seeding_time() const;
     std::vector<int> file_priorities() const;
     bool is_sequential_download() const;
+ #ifdef LIBTORRENT_0_15
+    bool super_seeding() const;
+#endif
+    QString creation_date() const;
+    void get_peer_info(std::vector<peer_info>&) const;
+#ifndef DISABLE_GUI
+    bool resolve_countries() const;
+#endif
+    bool priv() const;
+    bool first_last_piece_first() const;
+    QString root_path() const;
+    bool has_error() const;
+    void downloading_pieces(bitfield &bf) const;
 
     //
     // Setters
@@ -135,6 +155,20 @@ class QTorrentHandle {
     void auto_managed(bool) const;
     void force_recheck() const;
     void move_storage(QString path) const;
+ #ifdef LIBTORRENT_0_15
+    void super_seeding(bool on) const;
+    void flush_cache() const;
+#endif
+#ifndef DISABLE_GUI
+    void resolve_countries(bool r);
+#endif
+    void connect_peer(libtorrent::asio::ip::tcp::endpoint const& adr, int source = 0) const;
+    void set_peer_upload_limit(libtorrent::asio::ip::tcp::endpoint ip, int limit) const;
+    void set_peer_download_limit(libtorrent::asio::ip::tcp::endpoint ip, int limit) const;
+    void add_tracker(announce_entry const& url);
+    void prioritize_first_last_piece(bool b);
+    void rename_file(int index, QString name);
+    bool save_torrent_file(QString path);
 
     //
     // Operators
