@@ -29,12 +29,19 @@
  */
 
 #include "rss.h"
-#include <QTimer>
-#include <QUrl>
+#include "preferences.h"
+
+#if QT_VERSION < 0x040500
+#include <QMap>
+#define QHash QMap
+#define toHash toMap
+#else
+#include <QHash>
+#endif
 
 /** RssFolder **/
 
-RssFolder::RssFolder(RssFolder *parent, RssManager *rssmanager, bittorrent *BTSession, QString name): parent(parent), rssmanager(rssmanager), BTSession(BTSession), name(name) {
+RssFolder::RssFolder(RssFolder *parent, RssManager *rssmanager, Bittorrent *BTSession, QString name): parent(parent), rssmanager(rssmanager), BTSession(BTSession), name(name) {
   downloader = new downloadThread(this);
   connect(downloader, SIGNAL(downloadFinished(QString, QString)), this, SLOT(processFinishedDownload(QString, QString)));
   connect(downloader, SIGNAL(downloadFailure(QString, QString)), this, SLOT(handleDownloadFailure(QString, QString)));
@@ -62,7 +69,7 @@ RssFile::FileType RssFolder::getType() const {
 
 void RssFolder::refreshAll(){
   qDebug("Refreshing all rss feeds");
-  QList<RssFile*> items = this->values();
+  const QList<RssFile*> &items = this->values();
   for(int i=0; i<items.size(); ++i) {
     //foreach(RssFile *item, *this){
     RssFile *item = items.at(i);
@@ -83,8 +90,12 @@ void RssFolder::refreshAll(){
 }
 
 void RssFolder::removeFile(QString ID) {
-  if(this->contains(ID))
-    delete this->take(ID);
+  if(this->contains(ID)) {
+    RssFile* child = this->take(ID);
+    child->removeAllSettings();
+    child->removeAllItems();
+    delete child;
+  }
 }
 
 RssFolder* RssFolder::addFolder(QString name) {
@@ -120,7 +131,7 @@ void RssFolder::refresh() {
 QList<RssItem*> RssFolder::getNewsList() const {
   QList<RssItem*> news;
   foreach(RssFile *child, this->values()) {
-    news.append(child->getNewsList());
+    news << child->getNewsList();
   }
   return news;
 }
@@ -128,7 +139,7 @@ QList<RssItem*> RssFolder::getNewsList() const {
 QList<RssItem*> RssFolder::getUnreadNewsList() const {
   QList<RssItem*> unread_news;
   foreach(RssFile *child, this->values()) {
-    unread_news.append(child->getUnreadNewsList());
+    unread_news << child->getUnreadNewsList();
   }
   return unread_news;
 }
@@ -277,11 +288,10 @@ void RssFolder::addFile(RssFile * item) {
 
 /** RssManager **/
 
-RssManager::RssManager(bittorrent *BTSession): RssFolder(0, this, BTSession, QString::null) {
+RssManager::RssManager(Bittorrent *BTSession): RssFolder(0, this, BTSession, QString::null) {
   loadStreamList();
   connect(&newsRefresher, SIGNAL(timeout()), this, SLOT(refreshAll()));
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
-  refreshInterval = settings.value(QString::fromUtf8("Preferences/RSS/RSSRefresh"), 5).toInt();
+  refreshInterval = Preferences::getRSSRefreshInterval();
   newsRefresher.start(refreshInterval*60000);
 }
 
@@ -291,6 +301,14 @@ RssManager::~RssManager(){
   qDebug("RSSManager deleted");
 }
 
+void RssManager::updateRefreshInterval(unsigned int val){
+  if(refreshInterval != val) {
+    refreshInterval = val;
+    newsRefresher.start(refreshInterval*60000);
+    qDebug("New RSS refresh interval is now every %dmin", refreshInterval);
+  }
+}
+
 void RssManager::loadStreamList(){
   QSettings settings("qBittorrent", "qBittorrent");
   QStringList streamsUrl = settings.value("Rss/streamList").toStringList();
@@ -341,13 +359,15 @@ void RssManager::moveFile(RssFile* file, RssFolder* dest_folder) {
 }
 
 void RssManager::saveStreamList(){
-  QList<QPair<QString, QString> > streamsList;
   QStringList streamsUrl;
   QStringList aliases;
-  QList<RssStream*> streams = getAllFeeds();
-  foreach(RssStream *stream, streams) {
+  const QList<RssStream*> &streams = getAllFeeds();
+  foreach(const RssStream *stream, streams) {
     QString stream_path = stream->getPath().join("\\");
-    qDebug("Saving stream path: %s", stream_path.toLocal8Bit().data());
+    if(stream_path.isNull()) {
+      stream_path = "";
+    }
+    qDebug("Saving stream path: %s", qPrintable(stream_path));
     streamsUrl << stream_path;
     aliases << stream->getName();
   }
@@ -361,8 +381,7 @@ void RssManager::saveStreamList(){
 
 /** RssStream **/
 
-RssStream::RssStream(RssFolder* parent, RssManager *rssmanager, bittorrent *BTSession, QString _url): parent(parent), rssmanager(rssmanager), BTSession(BTSession), alias(""), iconPath(":/Icons/rss16.png"), refreshed(false), downloadFailure(false), currently_loading(false) {
-  has_attachments = false;
+RssStream::RssStream(RssFolder* parent, RssManager *rssmanager, Bittorrent *BTSession, QString _url): parent(parent), rssmanager(rssmanager), BTSession(BTSession), alias(""), iconPath(":/Icons/rss16.png"), refreshed(false), downloadFailure(false), currently_loading(false) {
   qDebug("RSSStream constructed");
   QSettings qBTRSS("qBittorrent", "qBittorrent-rss");
   url = QUrl(_url).toString();
@@ -374,8 +393,8 @@ RssStream::RssStream(RssFolder* parent, RssManager *rssmanager, bittorrent *BTSe
     RssItem *rss_item = RssItem::fromHash(this, item);
     if(rss_item->isValid()) {
       (*this)[rss_item->getTitle()] = rss_item;
-      if(rss_item->has_attachment())
-        has_attachments = true;
+    } else {
+      delete rss_item;
     }
   }
 }
@@ -416,6 +435,20 @@ void RssStream::removeAllItems() {
   this->clear();
 }
 
+void RssStream::removeAllSettings() {
+  QSettings qBTRSS("qBittorrent", "qBittorrent-rss");
+  QHash<QString, QVariant> feeds_w_downloader = qBTRSS.value("downloader_on", QHash<QString, QVariant>()).toHash();
+  if(feeds_w_downloader.contains(url)) {
+    feeds_w_downloader.remove(url);
+    qBTRSS.setValue("downloader_on", feeds_w_downloader);
+  }
+  QHash<QString, QVariant> all_feeds_filters = qBTRSS.value("feed_filters", QHash<QString, QVariant>()).toHash();
+  if(all_feeds_filters.contains(url)) {
+    all_feeds_filters.remove(url);
+    qBTRSS.setValue("feed_filters", all_feeds_filters);
+  }
+}
+
 bool RssStream::itemAlreadyExists(QString name) {
   return this->contains(name);
 }
@@ -529,82 +562,114 @@ QString RssStream::getIconUrl() {
 }
 
 // read and create items from a rss document
-short RssStream::readDoc(const QDomDocument& doc) {
+short RssStream::readDoc(QIODevice* device) {
+  qDebug("Parsing RSS file...");
+  QXmlStreamReader xml(device);
   // is it a rss file ?
-  QDomElement root = doc.documentElement();
-  if(root.tagName() == QString::fromUtf8("html")){
-    qDebug("the file is empty, maybe the url is invalid or the server is too busy");
+  if (xml.atEnd()) {
+    qDebug("ERROR: Could not parse RSS file");
     return -1;
   }
-  else if(root.tagName() != QString::fromUtf8("rss")){
-    qDebug("the file is not a rss stream, <rss> omitted: %s", root.tagName().toLocal8Bit().data());
-    return -1;
-  }
-  QDomNode rss = root.firstChild();
-  QDomElement channel = root.firstChild().toElement();
-
-  while(!channel.isNull()) {
-    // we are reading the rss'main info
-    if (channel.tagName() == "channel") {
-      QDomElement property = channel.firstChild().toElement();
-      while(!property.isNull()) {
-        if (property.tagName() == "title") {
-          title = property.text();
-          if(alias==getUrl())
-            rename(title);
-        }
-        else if (property.tagName() == "link")
-          link = property.text();
-        else if (property.tagName() == "description")
-          description = property.text();
-        else if (property.tagName() == "image")
-          image = property.text();
-        else if(property.tagName() == "item") {
-          RssItem * item = new RssItem(this, property);
-          if(item->isValid() && !itemAlreadyExists(item->getTitle())) {
-            (*this)[item->getTitle()] = item;
-            if(item->has_attachment()) {
-              has_attachments = true;
-              // Check if the item should be automatically downloaded
-              FeedFilter * matching_filter = FeedFilters::getFeedFilters(url).matches(item->getTitle());
-              if(matching_filter != 0) {
-                // Download the torrent
-                BTSession->addConsoleMessage(tr("Automatically downloading %1 torrent from %2 RSS feed...").arg(item->getTitle()).arg(getName()));
-                if(matching_filter->isValid()) {
-                  QString save_path = matching_filter->getSavePath();
-                  if(save_path.isEmpty())
-                    BTSession->downloadUrlAndSkipDialog(item->getTorrentUrl());
-                  else
-                    BTSession->downloadUrlAndSkipDialog(item->getTorrentUrl(), save_path);
-                } else {
-                  // All torrents are downloaded from this feed
-                  BTSession->downloadUrlAndSkipDialog(item->getTorrentUrl());
-                }
-                // Item was downloaded, consider it as Read
-                item->setRead();
-                // Clean up
-                delete matching_filter;
-              }
-            }
-          } else {
-            delete item;
-          }
-        }
-        property = property.nextSibling().toElement();
+  while (!xml.atEnd()) {
+    xml.readNext();
+    if(xml.isStartElement()) {
+      if(xml.name() != "rss") {
+        qDebug("ERROR: this is not a rss file, root tag is <%s>", qPrintable(xml.name().toString()));
+        return -1;
+      } else {
+        break;
       }
     }
-    channel = channel.nextSibling().toElement();
   }
+  // Read channels
+  while(!xml.atEnd()) {
+    xml.readNext();
+
+    if(xml.isEndElement())
+      break;
+
+    if(xml.isStartElement()) {
+      //qDebug("xml.name() == %s", qPrintable(xml.name().toString()));
+      if(xml.name() == "channel") {
+        qDebug("in channel");
+
+        // Parse channel content
+        while(!xml.atEnd()) {
+          xml.readNext();
+
+          if(xml.isEndElement() && xml.name() == "channel") {
+            break;
+          }
+
+          if(xml.isStartElement()) {
+            //qDebug("xml.name() == %s", qPrintable(xml.name().toString()));
+            if(xml.name() == "title") {
+              title = xml.readElementText();
+              if(alias == getUrl())
+                rename(title);
+            }
+            else if(xml.name() == "link") {
+              link = xml.readElementText();
+            }
+            else if(xml.name() == "description") {
+              description = xml.readElementText();
+            }
+            else if(xml.name() == "image") {
+              image = xml.attributes().value("url").toString();
+            }
+            else if(xml.name() == "item") {
+              RssItem * item = new RssItem(this, xml);
+              if(item->isValid() && !itemAlreadyExists(item->getTitle())) {
+                this->insert(item->getTitle(), item);
+              } else {
+                delete item;
+              }
+            }
+          }
+        }
+      }
+    }
+  }
+
   resizeList();
+
+  // RSS Feed Downloader
+  foreach(RssItem* item, values()) {
+    if(item->isRead()) continue;
+    QString torrent_url;
+    if(item->has_attachment())
+      torrent_url = item->getTorrentUrl();
+    else
+      torrent_url = item->getLink();
+    // Check if the item should be automatically downloaded
+    FeedFilter * matching_filter = FeedFilters::getFeedFilters(url).matches(item->getTitle());
+    if(matching_filter != 0) {
+      // Download the torrent
+      BTSession->addConsoleMessage(tr("Automatically downloading %1 torrent from %2 RSS feed...").arg(item->getTitle()).arg(getName()));
+      if(matching_filter->isValid()) {
+        QString save_path = matching_filter->getSavePath();
+        if(save_path.isEmpty())
+          BTSession->downloadUrlAndSkipDialog(torrent_url);
+        else
+          BTSession->downloadUrlAndSkipDialog(torrent_url, save_path);
+      } else {
+        // All torrents are downloaded from this feed
+        BTSession->downloadUrlAndSkipDialog(torrent_url);
+      }
+      // Item was downloaded, consider it as Read
+      item->setRead();
+      // Clean up
+      delete matching_filter;
+    }
+  }
   return 0;
 }
 
 void RssStream::resizeList() {
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
-  unsigned int max_articles = settings.value(QString::fromUtf8("Preferences/RSS/RSSMaxArticlesPerFeed"), 100).toInt();
+  unsigned int max_articles = Preferences::getRSSMaxArticlesPerFeed();
   unsigned int nb_articles = this->size();
   if(nb_articles > max_articles) {
-    QList<RssItem*> listItem = sortNewsList(this->values());
+    QList<RssItem*> listItem = RssManager::sortNewsList(this->values());
     int excess = nb_articles - max_articles;
     for(int i=0; i<excess; ++i){
       RssItem *lastItem = listItem.takeLast();
@@ -616,7 +681,6 @@ void RssStream::resizeList() {
 // existing and opening test after download
 short RssStream::openRss(){
   qDebug("openRss() called");
-  QDomDocument doc("Rss Seed");
   QFile fileRss(filePath);
   if(!fileRss.open(QIODevice::ReadOnly | QIODevice::Text)) {
     qDebug("openRss error: open failed, no file or locked, %s", (const char*)filePath.toLocal8Bit());
@@ -625,16 +689,9 @@ short RssStream::openRss(){
     }
     return -1;
   }
-  if(!doc.setContent(&fileRss)) {
-    qDebug("can't read temp file, might be empty");
-    fileRss.close();
-    if(QFile::exists(filePath)) {
-      fileRss.remove();
-    }
-    return -1;
-  }
+
   // start reading the xml
-  short return_lecture = readDoc(doc);
+  short return_lecture = readDoc(&fileRss);
   fileRss.close();
   if(QFile::exists(filePath)) {
     fileRss.remove();
@@ -656,3 +713,4 @@ void RssStream::processDownloadedFile(QString file_path) {
 void RssStream::setDownloadFailed(){
   downloadFailure = true;
 }
+
