@@ -38,7 +38,7 @@
 #include <QDragMoveEvent>
 
 #include "rss_imp.h"
-#include "FeedDownloader.h"
+#include "feeddownloader.h"
 #include "feedList.h"
 #include "bittorrent.h"
 
@@ -71,10 +71,8 @@ void RSSImp::displayRSSListMenu(const QPoint& pos){
       myRSSListMenu.addSeparator();
       myRSSListMenu.addAction(actionCopy_feed_URL);
       if(selectedItems.size() == 1) {
-        if(((RssStream*)listStreams->getRSSItem(selectedItems.first()))->hasAttachments()) {
-          myRSSListMenu.addSeparator();
-          myRSSListMenu.addAction(actionRSS_feed_downloader);
-        }
+        myRSSListMenu.addSeparator();
+        myRSSListMenu.addAction(actionRSS_feed_downloader);
       }
     }
   }else{
@@ -92,8 +90,8 @@ void RSSImp::displayItemsListMenu(const QPoint&){
   if(selectedItems.size() > 0) {
     bool has_attachment = false;
     foreach(QTreeWidgetItem *item, selectedItems) {
-      qDebug("text(3) URL: %s", item->text(NEWS_URL_COL).toLocal8Bit().data());
-      qDebug("text(2) TITLE: %s", item->text(NEWS_TITLE_COL).toLocal8Bit().data());
+      qDebug("text(3) URL: %s", qPrintable(item->text(NEWS_URL_COL)));
+      qDebug("text(2) TITLE: %s", qPrintable(item->text(NEWS_TITLE_COL)));
       if(listStreams->getRSSItemFromUrl(item->text(NEWS_URL_COL))->getItem(item->text(NEWS_TITLE_COL))->has_attachment()) {
         has_attachment = true;
         break;
@@ -221,7 +219,7 @@ void RSSImp::deleteSelectedItems() {
       }
       RssFile *rss_item = listStreams->getRSSItem(item);
       // Notify TreeWidget
-      listStreams->itemRemoved(item);
+      listStreams->itemAboutToBeRemoved(item);
       // Actually delete the item
       rss_item->getParent()->removeFile(rss_item->getID());
       delete item;
@@ -256,7 +254,7 @@ void RSSImp::loadFoldersOpenState() {
         if(listStreams->getRSSItem(child)->getID() == name) {
           parent = child;
           parent->setExpanded(true);
-          qDebug("expanding folder %s", name.toLocal8Bit().data());
+          qDebug("expanding folder %s", qPrintable(name));
           break;
         }  
       }
@@ -269,7 +267,7 @@ void RSSImp::saveFoldersOpenState() {
   QList<QTreeWidgetItem*> items = listStreams->getAllOpenFolders();
   foreach(QTreeWidgetItem* item, items) {
     QString path = listStreams->getItemPath(item).join("\\");
-    qDebug("saving open folder: %s", path.toLocal8Bit().data());
+    qDebug("saving open folder: %s", qPrintable(path));
     open_folders << path;
   }
   QSettings settings("qBittorrent", "qBittorrent");
@@ -293,9 +291,7 @@ void RSSImp::downloadTorrent() {
     if(article->has_attachment()) {
       BTSession->downloadFromUrl(article->getTorrentUrl());
     } else {
-      QString link = article->getLink();
-      if(!link.isEmpty())
-        QDesktopServices::openUrl(QUrl(link));
+      BTSession->downloadFromUrl(article->getLink());
     }
   }
 }
@@ -322,17 +318,19 @@ void RSSImp::renameFiles() {
   do {
     newName = QInputDialog::getText(this, tr("Please choose a new name for this RSS feed"), tr("New feed name:"), QLineEdit::Normal, listStreams->getRSSItem(item)->getName(), &ok);
     // Check if name is already taken
-    if(ok && rss_item->getParent()->contains(newName)) {
-      QMessageBox::warning(0, tr("Name already in use"), tr("This name is already used by another item, please choose another one."));
-      ok = false;
+    if(ok) {
+      if(rss_item->getParent()->contains(newName)) {
+        QMessageBox::warning(0, tr("Name already in use"), tr("This name is already used by another item, please choose another one."));
+        ok = false;
+      }
+    } else {
+      return;
     }
   }while(!ok);
-  if(ok) {
-    // Rename item
-    rss_item->rename(newName);
-    // Update TreeWidget
-    updateItemInfos(item);
-  }
+  // Rename item
+  rss_item->rename(newName);
+  // Update TreeWidget
+  updateItemInfos(item);
 }
 
 //right-click on stream : refresh it
@@ -376,8 +374,10 @@ void RSSImp::copySelectedFeedsURL() {
 void RSSImp::showFeedDownloader() {
   QTreeWidgetItem* item = listStreams->selectedItems()[0];
   RssFile* rss_item = listStreams->getRSSItem(item);
-  if(rss_item->getType() == RssFile::STREAM)
-    new FeedDownloaderDlg(this, listStreams->getItemID(item), rss_item->getName(), BTSession);
+  if(rss_item->getType() == RssFile::STREAM) {
+    FeedDownloaderDlg* feedDownloader = new FeedDownloaderDlg(this, listStreams->getItemID(item), rss_item->getName(), BTSession);
+    connect(feedDownloader, SIGNAL(filteringEnabled()), this, SLOT(on_updateAllButton_clicked()));
+  }
 }
 
 void RSSImp::on_markReadButton_clicked() {
@@ -405,7 +405,7 @@ void RSSImp::fillFeedsList(QTreeWidgetItem *parent, RssFolder *rss_parent) {
       item = new QTreeWidgetItem(listStreams);
     else
       item = new QTreeWidgetItem(parent);
-    item->setData(0, Qt::DisplayRole, rss_child->getName()+ QString::fromUtf8("  (")+QString::number(rss_child->getNbUnRead(), 10)+QString(")"));
+    item->setData(0, Qt::DisplayRole, QVariant(rss_child->getName()+ QString::fromUtf8("  (")+QString::number(rss_child->getNbUnRead(), 10)+QString(")")));
     // Notify TreeWidget of item addition
     listStreams->itemAdded(item, rss_child);
     // Set Icon
@@ -427,13 +427,14 @@ void RSSImp::refreshNewsList(QTreeWidgetItem* item) {
   }
 
   RssFile *rss_item = listStreams->getRSSItem(item);
+  if(!rss_item) return;
 
   qDebug("Getting the list of news");
   QList<RssItem*> news;
   if(rss_item == rssmanager)
-    news = sortNewsList(rss_item->getUnreadNewsList());
-  else
-    news = sortNewsList(rss_item->getNewsList());
+    news = RssManager::sortNewsList(rss_item->getUnreadNewsList());
+  else if(rss_item)
+    news = RssManager::sortNewsList(rss_item->getNewsList());
   // Clear the list first
   textBrowser->clear();
   previous_news = 0;
@@ -442,10 +443,6 @@ void RSSImp::refreshNewsList(QTreeWidgetItem* item) {
   foreach(RssItem* article, news){
     QTreeWidgetItem* it = new QTreeWidgetItem(listNews);
     it->setText(NEWS_TITLE_COL, article->getTitle());
-    if(article->has_attachment())
-      it->setData(NEWS_TITLE_COL, Qt::DecorationRole, QVariant(QIcon(":/Icons/oxygen/application-x-kgetlist.png")));
-    else
-      it->setData(NEWS_TITLE_COL, Qt::DecorationRole, QVariant(QIcon(":/Icons/oxygen/application-x-kgetlist-no.png")));
     it->setText(NEWS_URL_COL, article->getParent()->getUrl());
     if(article->isRead()){
       it->setData(NEWS_TITLE_COL, Qt::ForegroundRole, QVariant(QColor("grey")));
@@ -460,8 +457,11 @@ void RSSImp::refreshNewsList(QTreeWidgetItem* item) {
 }
 
 // display a news
-void RSSImp::refreshTextBrowser(QTreeWidgetItem *item) {
-  if(!item || item == previous_news) return;
+void RSSImp::refreshTextBrowser() {
+  QList<QTreeWidgetItem*> selection = listNews->selectedItems();
+  if(selection.empty()) return;
+  QTreeWidgetItem *item = selection.first();
+  if(item == previous_news) return;
   // Stop displaying previous news if necessary
   if(listStreams->currentFeed() == listStreams->getUnreadItem()) {
     if(previous_news) {
@@ -476,7 +476,7 @@ void RSSImp::refreshTextBrowser(QTreeWidgetItem *item) {
   html += "<div style='border: 2px solid red; margin-left: 5px; margin-right: 5px; margin-bottom: 5px;'>";
   html += "<div style='background-color: #678db2; font-weight: bold; color: #fff;'>"+article->getTitle() + "</div>";
   if(article->getDate().isValid()) {
-    html += "<div style='background-color: #efefef;'><b>"+tr("Date: ")+"</b>"+article->getDate().toString()+"</div>";
+    html += "<div style='background-color: #efefef;'><b>"+tr("Date: ")+"</b>"+article->getDate().toLocalTime().toString(Qt::SystemLocaleLongDate)+"</div>";
   }
   if(!article->getAuthor().isEmpty()) {
     html += "<div style='background-color: #efefef;'><b>"+tr("Author: ")+"</b>"+article->getAuthor()+"</div>";
@@ -558,7 +558,11 @@ void RSSImp::updateFeedInfos(QString url, QString aliasOrUrl, unsigned int nbUnr
   }
 }
 
-RSSImp::RSSImp(bittorrent *BTSession) : QWidget(), BTSession(BTSession){
+void RSSImp::updateRefreshInterval(unsigned int val) {
+  rssmanager->updateRefreshInterval(val);
+}
+
+RSSImp::RSSImp(Bittorrent *BTSession) : QWidget(), BTSession(BTSession){
   setupUi(this);
 
   rssmanager = new RssManager(BTSession);
@@ -596,7 +600,7 @@ RSSImp::RSSImp(bittorrent *BTSession) : QWidget(), BTSession(BTSession){
   connect(listStreams, SIGNAL(foldersAltered(QList<QTreeWidgetItem*>)), this, SLOT(updateItemsInfos(QList<QTreeWidgetItem*>)));
   connect(listStreams, SIGNAL(overwriteAttempt(QString)), this, SLOT(displayOverwriteError(QString)));
 
-  connect(listNews, SIGNAL(itemClicked(QTreeWidgetItem*, int)), this, SLOT(refreshTextBrowser(QTreeWidgetItem *)));
+  connect(listNews, SIGNAL(itemSelectionChanged()), this, SLOT(refreshTextBrowser()));
   connect(listNews, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(downloadTorrent()));
 
   // Refresh all feeds
